@@ -23,19 +23,18 @@ use Aspect::Pointcut::Highest      ();
 use Aspect::Pointcut::Throwing     ();
 use Aspect::Pointcut::Wantarray    ();
 use Aspect::Advice                 ();
-use Aspect::AdviceContext          ();
-use Aspect::Advice::Around         ();
-use Aspect::Advice::Before         ();
 use Aspect::Advice::After          ();
 use Aspect::Advice::AfterReturning ();
 use Aspect::Advice::AfterThrowing  ();
+use Aspect::Advice::Around         ();
+use Aspect::Advice::Before         ();
 use Aspect::AdviceContext          ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 
 # Track the location of exported functions so that pointcuts
 # can avoid accidentally binding them.
-our %EXPORTED;
+our %EXPORTED = ();
 
 
 
@@ -795,7 +794,7 @@ L<Aspect::Library::Trace>
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 - 2011 Adam Kennedy.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
