@@ -12,7 +12,7 @@ use Aspect::Hook         ();
 use Aspect::Advice       ();
 use Aspect::Point::After ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -78,7 +78,6 @@ sub _install {
 				] };
 
 				local \$_ = bless {
-					type         => 'after',
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
@@ -111,7 +110,6 @@ sub _install {
 				};
 
 				local \$_ = bless {
-					type         => 'after',
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
@@ -120,6 +118,7 @@ sub _install {
 					pointcut     => \$pointcut,
 					original     => \$original,
 				}, 'Aspect::Point::After';
+
 				unless ( $MATCH_RUN ) {
 					return \$return unless \$_->{exception};
 					die \$_->{exception};
@@ -135,37 +134,36 @@ sub _install {
 				# Return the potentially-modified value
 				return \$_->{return_value};
 
-			} else {
-				eval {
-					Sub::Uplevel::uplevel(
-						2, \$original, \@_,
-					)
-				};
-
-				local \$_ = bless {
-					type         => 'after',
-					sub_name     => \$name,
-					wantarray    => \$wantarray,
-					params       => \\\@_,
-					return_value => undef,
-					exception    => \$\@,
-					pointcut     => \$pointcut,
-					original     => \$original,
-				}, 'Aspect::Point::After';
-				unless ( $MATCH_RUN ) {
-					return unless \$_->{exception};
-					die \$_->{exception};
-				}
-
-				# Execute the advice code
-				&\$code(\$_);
-
-				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
-				die \$exception if \$exception;
-
-				return;
 			}
+
+			eval {
+				Sub::Uplevel::uplevel(
+					2, \$original, \@_,
+				)
+			};
+
+			local \$_ = bless {
+				sub_name     => \$name,
+				wantarray    => \$wantarray,
+				params       => \\\@_,
+				return_value => undef,
+				exception    => \$\@,
+				pointcut     => \$pointcut,
+				original     => \$original,
+			}, 'Aspect::Point::After';
+			unless ( $MATCH_RUN ) {
+				return unless \$_->{exception};
+				die \$_->{exception};
+			}
+
+			# Execute the advice code
+			&\$code(\$_);
+
+			# Throw the same (or modified) exception
+			my \$exception = \$_->exception;
+			die \$exception if \$exception;
+
+			return;
 		};
 END_PERL
 	}
