@@ -12,7 +12,7 @@ use Aspect::Hook                  ();
 use Aspect::Advice                ();
 use Aspect::Point::AfterReturning ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -76,16 +76,17 @@ sub _install {
 						1, \$original, \@_,
 					)
 				];
+
 				local \$_ = bless {
-					type         => 'after_returning',
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => \$return,
-					exception    => undef,
+					exception    => '',
 					pointcut     => \$pointcut,
 					original     => \$original,
 				}, 'Aspect::Point::AfterReturning';
+
 				return \@\$return unless $MATCH_RUN;
 
 				# Execute the advice code
@@ -99,16 +100,17 @@ sub _install {
 				my \$return = Sub::Uplevel::uplevel(
 					1, \$original, \@_,
 				);
+
 				local \$_ = bless {
-					type         => 'after_returning',
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => \$return,
-					exception    => undef,
+					exception    => '',
 					pointcut     => \$pointcut,
 					original     => \$original,
 				}, 'Aspect::Point::AfterReturning';
+
 				return \$return unless $MATCH_RUN;
 
 				# Execute the advice code
@@ -119,16 +121,17 @@ sub _install {
 				Sub::Uplevel::uplevel(
 					1, \$original, \@_,
 				);
+
 				local \$_ = bless {
-					type         => 'after_returning',
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => undef,
-					exception    => undef,
+					exception    => '',
 					pointcut     => \$pointcut,
 					original     => \$original,
 				}, 'Aspect::Point::AfterReturning';
+
 				return unless $MATCH_RUN;
 
 				# Execute the advice code
