@@ -11,7 +11,7 @@ use Aspect::Hook          ();
 use Aspect::Advice        ();
 use Aspect::Point::Before ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 our @ISA     = 'Aspect::Advice';
 
 sub _install {
@@ -75,7 +75,6 @@ sub _install {
 			# Apply any runtime-specific context checks
 			my \$wantarray = wantarray;
 			local \$_ = bless {
-				type         => 'before',
 				sub_name     => \$name,
 				wantarray    => \$wantarray,
 				params       => \\\@_,
@@ -84,6 +83,7 @@ sub _install {
 				original     => \$original,
 				proceed      => 1,
 			}, 'Aspect::Point::Before';
+
 			goto &\$original unless $MATCH_RUN;
 
 			# Array context needs some special return handling
@@ -109,9 +109,7 @@ sub _install {
 			}
 
 			# Do they want to shortcut?
-			unless ( \$_->proceed ) {
-				return \$_->{return_value};
-			}
+			return \$_->{return_value} unless \$_->proceed;
 
 			# Continue onwards to the original function
 			\@_ = \$_->params;
