@@ -12,7 +12,7 @@ use Aspect::Modular                    ();
 use Aspect::Advice::Before             ();
 use Aspect::Library::Listenable::Event ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 our @ISA     = 'Aspect::Modular';
 
 sub import {
@@ -44,7 +44,7 @@ sub get_advice {
 
 			my $always_fire = delete $params{__always_fire};
 			my %old_state = get_listenable_state($listenable, \%params);
-			$context->run_original($context->params);
+			$context->original->( $context->params );
 			my %new_state = get_listenable_state($listenable, \%params);
 
 			return if
@@ -62,7 +62,7 @@ sub get_advice {
 				map {("old_$_" => $old_state{$_})} keys %old_state,
 			);
 
-			fire_event($event);	
+			fire_event($event);
 		},
 	);
 }
@@ -567,7 +567,7 @@ Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 - 2011 Adam Kennedy.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
