@@ -6,7 +6,7 @@ use Aspect::Modular        ();
 use Aspect::Advice::Before ();
 use Aspect::Pointcut::Call ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 our @ISA     = 'Aspect::Modular';
 
 my %CACHE = ();
@@ -22,7 +22,7 @@ sub get_advice {
 			if ( exists $CACHE{$class} ) {
 				$_->return_value($CACHE{$class});
 			} else {
-				$_->run_original;
+				$_->proceed;
 				unless ( $_->exception ) {
 					$CACHE{$class} = $_->return_value;
 				}
@@ -97,7 +97,7 @@ Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 - 2011 Adam Kennedy.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
