@@ -5,7 +5,7 @@ use warnings;
 use Carp         ();
 use Sub::Uplevel ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 
 
 
@@ -14,10 +14,10 @@ our $VERSION = '0.93_02';
 ######################################################################
 # Constructor and Built-In Accessors
 
-sub new {
-	my $class = shift;
-	bless { @_ }, $class;
-}
+# sub new {
+	# my $class = shift;
+	# bless { @_ }, $class;
+# }
 
 sub sub_name {
 	$_[0]->{sub_name};
@@ -27,13 +27,6 @@ sub wantarray {
 	$_[0]->{wantarray};
 }
 
-sub proceed {
-	unless ( defined $_[0]->{proceed} ) {
-		Carp::croak("The use of 'proceed' is meaningless in this advice");
-	}
-	@_ > 1 ? $_[0]->{proceed} = $_[1] : $_[0]->{proceed};
-}
-
 sub params_ref {
 	$_[0]->{params};
 }
@@ -67,95 +60,50 @@ sub append_params {
 # Higher Level Methods
 
 sub package_name {
-	my $self = shift;
-	my $name = $self->{sub_name};
+	my $name = $_[0]->{sub_name};
 	return '' unless $name =~ /::/;
 	$name =~ s/::[^:]+$//;
 	return $name;
 }
 
 sub short_sub_name {
-	my $self = shift;
-	my $name = $self->{sub_name};
+	my $name = $_[0]->{sub_name};
 	return $name unless $name =~ /::/;
 	$name =~ /::([^:]+)$/;
 	return $1;
 }
 
-sub run_original {
-	my $self = shift;
-	if ( $self->{wantarray} ) {
-		my $rv = [ Sub::Uplevel::uplevel(
-			2,
-			$self->original,
-			$self->params,
-		) ];
-		return $self->return_value($rv);
-	} elsif ( defined $self->{wantarray} ) {
-		my $rv = Sub::Uplevel::uplevel(
-			2,
-			$self->original,
-			$self->params,
-		);
-		return $self->return_value($rv);
-	} else {
-		Sub::Uplevel::uplevel(
-			2,
-			$self->original,
-			$self->params,
-		);
-		return;
-	}
-}
-
 sub return_value {
 	my $self = shift;
-	if ( @_ ) {
-		if ( $self->{wantarray} ) {
-			# Normalise list-wise return behaviour
-			# at mutation time, rather than everywhere else.
-			# NOTE: Reuse the current array reference. This
-			# causes the original return values to be cleaned
-			# up immediately, and allows for a small
-			# optimisation in the surrounding advice hook code.
-			$self->{return_value} = \@_;
-		} else {
-			$self->{return_value} = shift;
-		}
-		if ( defined $self->{exception} ) {
-			$self->{exception} = '';
-		}
-		$self->{proceed} = 0;
-	}
-	my $return_value = $self->get_value('return_value');
-	return (CORE::wantarray && ref $return_value eq 'ARRAY')
-		? @$return_value
-		: $return_value;
-}
 
-sub exception {
-	my $self = shift;
-	if ( @_ ) {
-		$self->{exception} = shift;
-		$self->{proceed}   = 0;
-	}
-	return $self->get_value('exception');
-}
+	if ( $self->{wantarray} ) {
+		return @{$self->{return_value}} unless @_;
 
-sub get_value {
-	my ($self, $key) = @_;
-	Carp::croak "Key does not exist: [$key]" unless exists $self->{$key};
-	my $value = $self->{$key};
-	return (CORE::wantarray && ref $value eq 'ARRAY')
-		? @$value
-		: $value;
+		# Normalise list-wise return behaviour
+		# at mutation time, rather than everywhere else.
+		# NOTE: Reuse the current array reference. This
+		# causes the original return values to be cleaned
+		# up immediately, and allows for a small
+		# optimisation in the surrounding advice hook code.
+		$self->{return_value} = \@_;
+		$self->{exception}    = '';
+		$self->{proceed}      = 0;
+		return @_;
+	}
+
+	return $self->{return_value} unless @_;
+
+	$self->{exception}    = '';
+	$self->{proceed}      = 0;
+	$self->{return_value} = shift;
 }
 
 sub AUTOLOAD {
 	my $self = shift;
 	my $key  = our $AUTOLOAD;
 	$key =~ s/^.*:://;
-	return $self->get_value($key);
+	Carp::croak "Key does not exist: [$key]" unless exists $self->{$key};
+	return $self->{$key};
 }
 
 # Improves performance by not having to send DESTROY calls
@@ -190,7 +138,7 @@ Aspect::Point - The Join Point context
      $context->append_param($rdbms);  # Append a param to sub call
      $context->append_params($a, $b); # Append params to sub call
      $context->return_value(4)        # Don't proceed and return immediately
-     $context->original->(x => 3);    # Call matched sub independantly
+     $context->original->(x => 3);    # Call matched sub independently
      $context->proceed(1);            # Continue to sub with context params
      print $context->company->name;   # Access cflow pointcut advice context
   } $pointcut;
@@ -296,7 +244,7 @@ Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 - 2011 Adam Kennedy.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
