@@ -40,7 +40,7 @@ use Aspect::Pointcut::Or  ();
 use Aspect::Pointcut::And ();
 use Aspect::Pointcut::Not ();
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.97_01';
 
 use overload (
 	# Keep traditional Perl boolification and stringification
@@ -133,7 +133,7 @@ BEGIN {
 
 =head2 match_all
 
-  my @fully_resolved_function_names = $pointcut->match_all();
+  my @fully_resolved_function_names = $pointcut->match_all;
 
 The C<match_all> method is the primary compile-time function called on the
 pointcut model by the core Aspect library.
@@ -224,7 +224,7 @@ sub match_all {
 
 =head2 match_define
 
-  my $should_hook = $pointcut->match_define();
+  my $should_hook = $pointcut->match_define;
 
 At compile time, the only common factor in predicting the future state of
 a function call is the name of the function itself.
@@ -270,6 +270,8 @@ sub compiled_weave {
 	return eval "sub () { $code }";
 }
 
+=pod
+
 =head2 compile_runtime
 
 The C<compile_runtime> method generates a custom function that is used to test
@@ -314,7 +316,7 @@ sub match_contains {
 
 =head2 match_curry
 
-  my $optimized_pointcut = $raw_pointcut->match_curry();
+  my $optimized_pointcut = $raw_pointcut->match_curry;
 
 In a production system, pointcut declarations can result in large and
 complex B<Aspect::Pointcut> object trees.
@@ -333,7 +335,7 @@ and to remove other tests that the currying process can determine will
 never need to be tested.
 
 The currying process will generate and return a new pointcut tree that is
-independant from the original, and that can perform a match test at the
+independent from the original, and that can perform a match test at the
 structurally minimum computational cost.
 
 Returns a new optimised B<Aspect::Pointcut> object if any further testing
@@ -370,7 +372,7 @@ Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 - 2011 Adam Kennedy.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
